@@ -21,11 +21,12 @@
 #define CLOCKWIDGET_H
 
 #include <QColor>
+#include <QLayout>
 #include <QSize>
 #include <QTimer>
 #include <QWidget>
 
-#include <QMouseEvent>
+#include "binarydisplaywidget.h"
 
 class ClockWidget : public QWidget
 {
@@ -47,6 +48,8 @@ signals:
 protected:
     bool showSeconds;
 
+    virtual void addBinaryDisplayWidget(BinaryDisplayWidget *widget, QLayout *layout);
+
 protected slots:
     virtual void updateTime() = 0;
 
