@@ -38,6 +38,9 @@ const int SettingsDialog::LED_SIZE_DEFAULT = 34;
 const QString SettingsDialog::SHOW_SECONDS = "show_seconds";
 const bool SettingsDialog::SHOW_SECONDS_DEFAULT = true;
 
+const QString SettingsDialog::USE_GRAY_CODE = "use_gray_code";
+const bool SettingsDialog::USE_GRAY_CODE_DEFAULT = false;
+
 #ifndef Q_WS_MAEMO_5
 const QString SettingsDialog::POSITION = "position";
 const QPoint SettingsDialog::POSITION_DEFAULT = QPoint(10, 10);
@@ -72,9 +75,13 @@ SettingsDialog::SettingsDialog(QWidget *parent) :
                                              SettingsDialog::LED_BORDER_DEFAULT).toInt());
     ui->ledSizeSpinBox->setValue(settings.value(SettingsDialog::LED_SIZE,
                                              SettingsDialog::LED_SIZE_DEFAULT).toInt());
+
     ui->showSecondsCheckBox->setChecked(settings.value(SettingsDialog::SHOW_SECONDS,
                                                        SettingsDialog::SHOW_SECONDS_DEFAULT).toBool());
 
+    ui->useGrayCodeCheckBox->setChecked(settings.value(SettingsDialog::USE_GRAY_CODE,
+                                                       SettingsDialog::USE_GRAY_CODE_DEFAULT).toBool());
+
 #ifndef Q_WS_MAEMO_5
     ui->transparencySupportCheckBox->setChecked(settings.value(SettingsDialog::TRANSPARENCY,
                                                                SettingsDialog::TRANSPARENCY_DEFAULT).toBool());
@@ -112,6 +119,8 @@ void SettingsDialog::accept(){
 
     settings.setValue(SettingsDialog::SHOW_SECONDS, ui->showSecondsCheckBox->isChecked());
 
+    settings.setValue(SettingsDialog::USE_GRAY_CODE, ui->useGrayCodeCheckBox->isChecked());
+
 #ifndef Q_WS_MAEMO_5
     settings.setValue(SettingsDialog::TRANSPARENCY, ui->transparencySupportCheckBox->isChecked());
     settings.setValue(SettingsDialog::WIDGET_PLACEMENT, ui->widgetPlacementComboBox->currentIndex());
