@@ -27,21 +27,17 @@ UnixTimeWidget::UnixTimeWidget(QWidget *parent) :
     layout = new QVBoxLayout(this);
 
     fourthByte = new HorizontalBinaryDisplayWidget(8, 0);
-    connect(this, SIGNAL(settingsChanged()), fourthByte, SLOT(applySettings()));
-    layout->addWidget(fourthByte);
+    addBinaryDisplayWidget(fourthByte, layout);
 
     thirdByte = new HorizontalBinaryDisplayWidget(8, 1);
-    connect(this, SIGNAL(settingsChanged()), thirdByte, SLOT(applySettings()));
-    layout->addWidget(thirdByte);
+    addBinaryDisplayWidget(thirdByte, layout);
 
     secondByte = new HorizontalBinaryDisplayWidget(8, 1);
-    connect(this, SIGNAL(settingsChanged()), secondByte, SLOT(applySettings()));
-    layout->addWidget(secondByte);
+    addBinaryDisplayWidget(secondByte, layout);
 
     if(showSeconds){
         firstByte = new HorizontalBinaryDisplayWidget(8, 1);
-        connect(this, SIGNAL(settingsChanged()), firstByte, SLOT(applySettings()));
-        layout->addWidget(firstByte);
+        addBinaryDisplayWidget(firstByte, layout);
     }else{
         firstByte = NULL;
     }
