@@ -19,20 +19,20 @@
 
 #include "verticalbinarydisplaywidget.h"
 
-VerticalBinaryDisplayWidget::VerticalBinaryDisplayWidget(int bits, int value, int height, QWidget *parent) :
-    BinaryDisplayWidget(bits, value, height, parent)
+VerticalBinaryDisplayWidget::VerticalBinaryDisplayWidget(int bits, int value, int widgetSize, QWidget *parent) :
+    BinaryDisplayWidget(bits, value, widgetSize, parent)
 {
 }
 
 void VerticalBinaryDisplayWidget::draw(QPainter *painter){
     for(int i = 0; i < bits; i++){
         drawLed(0,
-                ((height - bits) * baseSize) + (baseSize * i),
+                ((widgetSize - bits) * getElementSize()) + (getElementSize() * i),
                 ((value & (1 << (bits - i - 1))) > 0),
                 painter);
     }
 }
 
 QSize VerticalBinaryDisplayWidget::sizeHint(){
-    return QSize(baseSize, baseSize * height);
+    return QSize(getElementSize(), ledSize * getElementSize());
 }
